@@ -123,49 +123,58 @@ def sync_table(conn_info, stream, state, desired_columns, md_map):
 
             limitsize = post_db.CURSOR_ITER_SIZE - 1
             xmin = singer.get_bookmark(state, stream['tap_stream_id'], 'xmin')
+            columns = ','.join(escaped_columns)
+            fq_table_name = post_db.fully_qualified_table_name(schema_name, stream['table_name'])
+            attemps = 0
             while True:
-                with conn.cursor(cursor_factory=psycopg2.extras.DictCursor, name='stitch_cursor') as cur:
-                    cur.itersize = post_db.CURSOR_ITER_SIZE
-                    fq_table_name = post_db.fully_qualified_table_name(schema_name, stream['table_name'])
-                    if xmin:
-                        LOGGER.info("Resuming Full Table replication %s from xmin %s", nascent_stream_version, xmin)
-                        select_sql = """SELECT {}, xmin::text::bigint
-                                          FROM {} where age(xmin::xid) <= age('{}'::xid)
-                                         ORDER BY xmin::text ASC limit {}""".format(','.join(escaped_columns),
-                                                                           fq_table_name,
-                                                                           xmin,
-                                                                           limitsize)
-                    else:
-                        LOGGER.info("Beginning new Full Table replication %s", nascent_stream_version)
-                        select_sql = """SELECT {}, xmin::text::bigint
-                                          FROM {}
-                                         ORDER BY xmin::text ASC limit {}}""".format(','.join(escaped_columns),
-                                                                           fq_table_name,
-                                                                           limitsize)
+                try:
+                    with conn.cursor(cursor_factory=psycopg2.extras.DictCursor, name='stitch_cursor') as cur:
+                        cur.itersize = post_db.CURSOR_ITER_SIZE
+                        if xmin:
+                            LOGGER.info("Resuming Full Table replication %s from xmin %s", nascent_stream_version, xmin)
+                            select_sql = """SELECT {}, xmin::text::bigint
+                                              FROM {} where age(xmin::xid) <= age('{}'::xid)
+                                             ORDER BY xmin::text ASC limit {}""".format(columns,
+                                                                               fq_table_name,
+                                                                               xmin,
+                                                                               limitsize)
+                        else:
+                            LOGGER.info("Beginning new Full Table replication %s", nascent_stream_version)
+                            select_sql = """SELECT {}, xmin::text::bigint
+                                              FROM {}
+                                             ORDER BY xmin::text ASC limit {}}""".format(columns,
+                                                                               fq_table_name,
+                                                                               limitsize)
 
-                    LOGGER.info("select %s with itersize %s", select_sql, cur.itersize)
-                    cur.execute(select_sql)
+                        LOGGER.info("select %s with itersize %s", select_sql, cur.itersize)
+                        cur.execute(select_sql)
 
-                    rows_saved = 0
-                    for rec in cur:
-                        xmin = rec['xmin']
-                        rec = rec[:-1]
-                        record_message = post_db.selected_row_to_singer_message(stream,
-                                                                                rec,
-                                                                                nascent_stream_version,
-                                                                                desired_columns,
-                                                                                time_extracted,
-                                                                                md_map)
-                        singer.write_message(record_message)
-                        state = singer.write_bookmark(state, stream['tap_stream_id'], 'xmin', xmin)
-                        rows_saved = rows_saved + 1
-                        if rows_saved % UPDATE_BOOKMARK_PERIOD == 0:
-                            singer.write_message(singer.StateMessage(value=copy.deepcopy(state)))
+                        rows_saved = 0
+                        for rec in cur:
+                            xmin = rec['xmin']
+                            rec = rec[:-1]
+                            record_message = post_db.selected_row_to_singer_message(stream,
+                                                                                    rec,
+                                                                                    nascent_stream_version,
+                                                                                    desired_columns,
+                                                                                    time_extracted,
+                                                                                    md_map)
+                            singer.write_message(record_message)
+                            state = singer.write_bookmark(state, stream['tap_stream_id'], 'xmin', xmin)
+                            rows_saved = rows_saved + 1
+                            if rows_saved % UPDATE_BOOKMARK_PERIOD == 0:
+                                singer.write_message(singer.StateMessage(value=copy.deepcopy(state)))
 
-                        counter.increment()
+                            counter.increment()
 
-                    if rows_saved == 0:
-                        break
+                        if rows_saved == 0:
+                            break
+                    attemps = 0
+                except Exception as e:
+                    attemps = attemps + 1
+                    LOGGER.warn("error on SQL: %s. Message: %s", select_sql, e)
+                    if attemps > 3:
+                        raise e
 
     # once we have completed the full table replication, discard the xmin bookmark.
     # the xmin bookmark only comes into play when a full table replication is interrupted
